from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _

class Piece(models.Model):

    class Meta:
        verbose_name = _('Piece')
        verbose_name_plural = _('Pieces')
        ordering = ['title']

    title = models.CharField(_('Title'), max_length=50)
    reference = models.CharField(_('Reference'), max_length=50, blank=True)
    comment = models.TextField(_('Comment'), blank=True)
    location = models.TextField(_('Location'), blank=True)
    image = models.ImageField(_('Picture'),
            upload_to='matos', max_length=250, null=True, blank=True)

    rentable = models.BooleanField(_('Rentable'), default=False)

    purchase_date = models.DateField(_('Purchase Date'), null=True, blank=True)
    purchase_price = models.DecimalField(_('Purchase Price'),
            max_digits=10, decimal_places=2, null=True, blank=True)

    creation_timestamp = models.DateTimeField(auto_now_add=True, null=True)
    last_update_timestamp = models.DateTimeField(auto_now=True, null=True)

    def get_absolute_url(self):
        return reverse('piece-view', kwargs={'pk': self.id})
